@@ -47,6 +47,7 @@ has 'group_limit'                 => ( is => 'rw', isa => 'Num',      default  =
 has 'core_definition'             => ( is => 'rw', isa => 'Num',      default  => 1.0 );
 has 'verbose'                     => ( is => 'rw', isa => 'Bool',     default  => 0 );
 has 'mafft'                       => ( is => 'ro', isa => 'Bool',     default  => 0 );
+has 'inflation_value'             => ( is => 'rw', isa => 'Num',      default  => 1.5 );
 
 has 'output_multifasta_files' => ( is => 'ro', isa => 'Bool', default => 0 );
 
@@ -108,6 +109,7 @@ sub run {
         mcl_exec        => $self->mcl_exec,
         job_runner      => $self->job_runner,
         cpus            => $self->cpus,
+	inflation_value => $self->inflation_value,
         output_file     => $output_mcl_filename
     );
     $mcl->run();
